@@ -169,6 +169,8 @@ void draw_turtle_helper(void) {
     save_pen(&saved_pen);
     plain_xor_pen();
     pen_vis = 0;
+    set_pen_width(1);
+    set_pen_height(1);
     
     real_heading = -turtle_heading + 90.0;
 	
@@ -250,10 +252,10 @@ NODE *lleft(NODE *arg) {
     return(UNBOUND);
 }
 
-int wrap_right(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
-int wrap_left(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
-int wrap_up(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
-int wrap_down(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
+FLONUM wrap_right(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
+FLONUM wrap_left(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
+FLONUM wrap_up(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
+FLONUM wrap_down(FLONUM, FLONUM, FLONUM, FLONUM, FLONUM);
 
 void forward(FLONUM d) {
     prepare_to_draw;
@@ -267,8 +269,10 @@ void forward(FLONUM d) {
 }
 
 void forward_helper(FLONUM d) {
-    FLONUM real_heading, dx, dy, x1, y1, x2, y2;
-    
+    FLONUM real_heading, dx, dy, x1, y1, x2, y2, newd = 0.0;
+
+wraploop:
+    if (newd != 0.0) d = newd;
     real_heading = -turtle_heading + 90.0;
     x1 = screen_x_coord;
     y1 = screen_y_coord;
@@ -299,12 +303,12 @@ void forward_helper(FLONUM d) {
 	turtle_y = turtle_y + dy;
 	line_to(g_round(x2), g_round(y2));
 	save_line();
+    } else {
+	if (newd = wrap_right(d, x1, y1, x2, y2)) goto wraploop;
+	if (newd = wrap_left(d, x1, y1, x2, y2)) goto wraploop;
+	if (newd = wrap_up(d, x1, y1, x2, y2)) goto wraploop;
+	if (newd = wrap_down(d, x1, y1, x2, y2)) goto wraploop;
     }
-    else
-	if (!wrap_right(d, x1, y1, x2, y2))
-	    if (!wrap_left(d, x1, y1, x2, y2))
-		if (!wrap_up(d, x1, y1, x2, y2))
-		    wrap_down(d, x1, y1, x2, y2);
 
     if (internal_penmode == PENMODE_REVERSE && pen_vis == 0 && d < 0.0) {
 	line_to(g_round(screen_x_coord), g_round(screen_y_coord));
@@ -312,7 +316,7 @@ void forward_helper(FLONUM d) {
     }
 }
 
-int wrap_right(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
+FLONUM wrap_right(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
     FLONUM yi, newd;
     
     if (x2 > screen_right) {
@@ -325,17 +329,17 @@ int wrap_right(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
 	    turtle_y = screen_y_center - yi;
 	    if (current_mode == wrapmode) {
 		newd = d * ((x2 - screen_right - 1)/(x2 - x1));
-		if (newd*d > 0) forward_helper(newd);
-		return(1);
+		if (newd*d > 0) return(newd);
+	    } else {
+		turtle_x = turtle_right_max;
+		err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	    }
-	    turtle_x = turtle_right_max;
-	    err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	}
     }
-    return(0);
+    return(0.0);
 }
 
-int wrap_left(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
+FLONUM wrap_left(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
     FLONUM yi, newd;
     
     if (x2 < screen_left) {
@@ -348,17 +352,17 @@ int wrap_left(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
 	    turtle_y = screen_y_center - yi;
 	    if (current_mode == wrapmode) {
 		newd = d * ((x2 + 1 - screen_left)/(x2 - x1));
-		if (newd*d > 0) forward_helper(newd);
-		return(1);
+		if (newd*d > 0) return(newd);
+	    } else {
+		turtle_x = turtle_left_max;
+		err_logo(TURTLE_OUT_OF_BOUNDS, NIL);	    
 	    }
-	    turtle_x = turtle_left_max;
-	    err_logo(TURTLE_OUT_OF_BOUNDS, NIL);	    
 	}
     }
-    return(0);
+    return(0.0);
 }
 
-int wrap_up(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
+FLONUM wrap_up(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
     FLONUM xi, newd;
     
     if (y2 < screen_top) {
@@ -371,17 +375,17 @@ int wrap_up(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
 	    turtle_y = turtle_bottom_max;
 	    if (current_mode == wrapmode) {
 		newd = d * ((y2 + 1 - screen_top)/(y2 - y1));
-		if (newd*d > 0) forward_helper(newd);
-		return(1);
+		if (newd*d > 0) return(newd);
+	    } else {
+		turtle_y = turtle_top_max;
+		err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	    }
-	    turtle_y = turtle_top_max;
-	    err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	}
     }
-    return(0);
+    return(0.0);
 }
 
-int wrap_down(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
+FLONUM wrap_down(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
     FLONUM xi, newd;
     
     if (y2 > screen_bottom) {
@@ -394,14 +398,14 @@ int wrap_down(FLONUM d, FLONUM x1, FLONUM y1, FLONUM x2, FLONUM y2) {
 	    turtle_y = turtle_top_max;
 	    if (current_mode == wrapmode) {
 		newd = d * ((y2 - screen_bottom - 1)/(y2 - y1));
-		if (newd*d > 0) forward_helper(newd);
-		return(1);
+		if (newd*d > 0) return(newd);
+	    } else {
+		turtle_y = turtle_bottom_max;
+		err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	    }
-	    turtle_y = turtle_bottom_max;
-	    err_logo(TURTLE_OUT_OF_BOUNDS, NIL);
 	}
     }
-    return(0);
+    return(0.0);
 }
 
 NODE *lforward(NODE *arg) {
