@@ -284,6 +284,10 @@ PRIMTYPE prims[] = {
     {"setread", 1, 1, 1, PREFIX_PRIORITY, lsetread},
     {"setreadpos", 1, 1, 1, PREFIX_PRIORITY, lsetreadpos},
     {"setscrunch", 2, 2, 2, PREFIX_PRIORITY, lsetscrunch},
+#ifdef WIN32
+    {"settc", 2, 2, 2, PREFIX_PRIORITY, set_text_color},
+    {"settextcolor", 2, 2, 2, PREFIX_PRIORITY, set_text_color},
+#endif
     {"setwrite", 1, 1, 1, PREFIX_PRIORITY, lsetwrite},
     {"setwritepos", 1, 1, 1, PREFIX_PRIORITY, lsetwritepos},
     {"setx", 1, 1, 1, PREFIX_PRIORITY, lsetx},
