@@ -23,6 +23,13 @@
 #ifndef _LOGO_H
 #define _LOGO_H
 
+/********** NOTE NOTE NOTE
+    #define SIG_TAKES_ARG
+ if on your Unix system the procedure that handles a signal must
+ take an integer argument.  This is true in some versions and not
+ others.
+ ***********/
+
 /* #define MEM_DEBUG */
 
 #define ecma	/* for European extended character set using parity bit */
@@ -31,6 +38,7 @@
 #define ibm
 #undef __ZTC__
 #define HAVE_MEMCPY
+#define SIG_TAKES_ARG
 #endif
 
 #ifdef THINK_C
@@ -45,6 +53,7 @@
 #ifdef __ZTC__
 #define ibm
 #define HAVE_MEMCPY
+#define SIG_TAKES_ARG
 #endif
 
 #ifdef _MSC_VER
