@@ -72,7 +72,7 @@ void unblock_input(void) {
     }
 }
 
-#if defined(__ZTC__) || defined(WIN32)
+#ifdef SIG_TAKES_ARG
 void logo_stop(int sig)
 #else
 void logo_stop(void)
@@ -96,7 +96,7 @@ void logo_stop(void)
     unblock_input();
 }
 
-#if defined(__ZTC__) || defined(WIN32)
+#ifdef SIG_TAKES_ARG
 void logo_pause(int sig)
 #else
 void logo_pause(void)
@@ -163,7 +163,7 @@ int main(int argc, char *argv[]) {
 #endif
       {
 	lcleartext(NIL);
-	ndprintf(stdout,"Welcome to Berkeley Logo version 4.1");
+	ndprintf(stdout,"Welcome to Berkeley Logo version 4.2");
 	new_line(stdout);
       }
     }
