@@ -106,7 +106,7 @@ NODE *lrerandom(NODE *arg) {
 jmp_buf oflo_buf;
 BOOLEAN handling_oflo = FALSE;
 
-#if defined(__ZTC__) || defined(WIN32)
+#ifdef SIG_TAKES_ARG
 #define sig_arg 0
 void handle_oflo(int sig) {
 #else
