@@ -601,8 +601,8 @@ void restore_pen(pen_info *p) {
     MoveCursor(p->h, p->v);
     turtlePen.mode = p->mode;
     win32_set_pen_mode(turtlePen.mode);
-    turtlePen.width = p->width;
-    if (p->color != pen_color) {
+    if (p->color != pen_color || p->width != turtlePen.width) {
+        turtlePen.width = p->width;
         pen_color = p->color;
         DeleteObject(turtlePen.hpen);
         turtlePen.hpen = CreatePen(PS_SOLID, turtlePen.width, palette[pen_color]);
@@ -764,11 +764,12 @@ void win32_con_split_screen(void) {
         return;
     in_graphics_mode = in_splitscreen = 1;
 
+    ShowWindow(hConWnd, SW_SHOW);
     vert = upscroll_text(3);
     GetClientRect(hMainWnd, &r);
     MoveWindow(hConWnd, 0, r.bottom - vert - 6, r.right, vert + 6, FALSE);
     MoveWindow(hGraphWnd, 0, 0, r.right, r.bottom - vert - 8, TRUE);
-    ShowWindow(hGraphWnd, SW_SHOW);
+    ShowWindow(hGraphWnd, SW_HIDE);
     BeginPaint(hGraphWnd, &ps);
     BitBlt(ps.hdc, 0, 0, maxX, maxY, memGraphDC, 0, 0, SRCCOPY);
     EndPaint(hGraphWnd, &ps);
@@ -781,6 +782,7 @@ void win32_con_split_screen(void) {
         resize_record(deltaX, deltaY);
         redraw_graphics();
     }
+    ShowWindow(hGraphWnd, SW_SHOW);
     if (!seen_once) {
         seen_once = TRUE;
         lclearscreen(NIL);
@@ -1079,3 +1081,19 @@ void ibm_plain_mode(void) {
     SetBkColor(memConDC, RGB(255, 255, 255));
     SetBkColor(ConDC, RGB(255, 255, 255));
 }
+
+NODE *set_text_color(NODE *args) {
+    int fore, back;
+
+    fore = getint(pos_int_arg(args));
+    if (NOT_THROWING) {
+        back = getint(pos_int_arg(cdr(args)));
+        if (NOT_THROWING) {
+           SetTextColor(memConDC, palette[fore]);
+           SetTextColor(ConDC, palette[fore]);
+           SetBkColor(memConDC, palette[back]);
+           SetBkColor(ConDC, palette[back]);
+        }
+    }
+    return UNBOUND;
+}
