@@ -291,6 +291,9 @@ NODE *to_helper(NODE *args, BOOLEAN macro_flag) {
 	to_pending++;    /* for int or quit signal */
 	while (NOT_THROWING && to_pending && (!feof(loadstream))) {
 	    tnode = cons(reader(loadstream, "> "), NIL);
+	    if ((feof(loadstream))) {
+		tnode = cons(make_static_strnode("end"), NIL);
+	    }
 	    setcdr(lastnode2, tnode);
 	    lastnode2 = tnode;
 	    tnode = cons(parser(car(tnode), TRUE), NIL);
